
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef GPS_TCLSERV_CLIENT_ERROR_H
#define GPS_TCLSERV_CLIENT_ERROR_H

#include <server/GPSError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum GPS_error {
	E_GPS_OK					  			= 0,

	/* module errors */
	E_GPS_NOT_FOUND                      = S_GPS_NOT_FOUND,
	E_GPS_CANNOT_WRITE_FILE              = S_GPS_CANNOT_WRITE_FILE,
	E_GPS_CANNOT_OPEN_FILE               = S_GPS_CANNOT_OPEN_FILE,
	E_GPS_ORDER_NOT_ALLOWED              = S_GPS_ORDER_NOT_ALLOWED,
	E_GPS_CANNOT_RECONNECT               = S_GPS_CANNOT_RECONNECT,
	E_GPS_CANNOT_DISCONNECT              = S_GPS_CANNOT_DISCONNECT,
	E_GPS_FAILED_WRITE                   = S_GPS_FAILED_WRITE,
	E_GPS_CANNOT_CONNECT                 = S_GPS_CANNOT_CONNECT,
	E_GPS_FAILED_READ                    = S_GPS_FAILED_READ,
	E_GPS_CANNOT_READ_HEADING            = S_GPS_CANNOT_READ_HEADING,
	E_GPS_CANNOT_READ_ATTITUDE           = S_GPS_CANNOT_READ_ATTITUDE,
	E_GPS_CANNOT_READ_POM                = S_GPS_CANNOT_READ_POM,


	/* std errors */
	E_GPS_ACTIVITY_INTERRUPTED           = S_GPS_stdGenoM_ACTIVITY_INTERRUPTED,
	E_GPS_TOO_MANY_ACTIVITIES            = S_GPS_stdGenoM_TOO_MANY_ACTIVITIES,
	E_GPS_ACTIVITY_FAILED                = S_GPS_stdGenoM_ACTIVITY_FAILED,
	E_GPS_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_GPS_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_GPS_UNKNOWN_ACTIVITY               = S_GPS_stdGenoM_UNKNOWN_ACTIVITY,
	E_GPS_FORBIDDEN_ACTIVITY_TRANSITION  = S_GPS_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_GPS_SYSTEM_ERROR                   = S_GPS_stdGenoM_SYSTEM_ERROR,
	E_GPS_ACTIVITY_ALREADY_ENDED         = S_GPS_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_GPS_WAIT_INIT_RQST                 = S_GPS_stdGenoM_WAIT_INIT_RQST,
	E_GPS_CONTROL_CODEL_ERROR            = S_GPS_stdGenoM_CONTROL_CODEL_ERROR,
	E_GPS_EXEC_TASK_SUSPENDED            = S_GPS_stdGenoM_EXEC_TASK_SUSPENDED,
	E_GPS_BAD_BLOCK_TYPE                 = S_GPS_stdGenoM_BAD_BLOCK_TYPE,
	E_GPS_BAD_POSTER_TYPE                = S_GPS_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum GPS_error GPS_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int GPS_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the GPS context.
 *
 * Returns NULL in case of failure
 */
const char* GPS_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
